summaryrefslogtreecommitdiffstats
path: root/sys
diff options
context:
space:
mode:
authorarchie <archie@FreeBSD.org>2000-09-19 03:22:06 +0000
committerarchie <archie@FreeBSD.org>2000-09-19 03:22:06 +0000
commitcfb71271f0ade8edcbb29563e6666bc265097092 (patch)
tree410cfb320d1cd336e281c6bccde3b03d53246fbb /sys
parentd9fb5a86b56083f3745311a60c12fc62fa4e8736 (diff)
downloadFreeBSD-src-cfb71271f0ade8edcbb29563e6666bc265097092.zip
FreeBSD-src-cfb71271f0ade8edcbb29563e6666bc265097092.tar.gz
Rename "struct session" to "struct sess_con" to avoid conflict with
upcoming "struct session" in proc.h. Requested by: jasone
Diffstat (limited to 'sys')
-rw-r--r--sys/netgraph/ng_pppoe.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/sys/netgraph/ng_pppoe.c b/sys/netgraph/ng_pppoe.c
index be43cd4..a74db26 100644
--- a/sys/netgraph/ng_pppoe.c
+++ b/sys/netgraph/ng_pppoe.c
@@ -134,16 +134,16 @@ typedef struct sess_neg *negp;
/*
* Session information that is needed after connection.
*/
-struct session {
+struct sess_con {
hook_p hook;
u_int16_t Session_ID;
- struct session *hash_next; /* not yet uesed */
enum state state;
char creator[NG_NODELEN + 1]; /* who to notify */
struct pppoe_full_hdr pkt_hdr; /* used when connected */
negp neg; /* used when negotiating */
+ /*struct sess_con *hash_next;*/ /* not yet used */
};
-typedef struct session *sessp;
+typedef struct sess_con *sessp;
/*
* Information we store for each node
@@ -155,7 +155,7 @@ struct PPPOE {
u_int packets_in; /* packets in from ethernet */
u_int packets_out; /* packets out towards ethernet */
u_int32_t flags;
/*struct session *buckets[HASH_SIZE];*/ /* not yet used */
};
typedef struct PPPOE *priv_p;
OpenPOWER on IntegriCloud
@@ -155,7 +155,7 @@ struct PPPOE {
u_int packets_out; /* packets out towards ethernet */
u_int32_t flags;
- /*struct session *buckets[HASH_SIZE];*/ /* not yet used */
+ /*struct sess_con *buckets[HASH_SIZE];*/ /* not yet used */
};
typedef struct PPPOE *priv_p;